# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import winrt.system
from winrt._winrt_windows_media_core_preview import (
    SoundLevelBroker,
)

__all__ = [
    "SoundLevelBroker",
]

